@@ -27,3 +27,16 @@ class JavaScriptResourceInsert(Response):
 		"""
 
 		super().__init__(request, http_response, data)
+		if not self.is_success():
+			return
+
+		self.data['data'] = merchantapi.model.JavaScriptResource(self.data['data'])
+
+	def get_javascript_resource(self) -> merchantapi.model.JavaScriptResource:
+		"""
+		Get javascript_resource.
+
+		:returns: JavaScriptResource
+		"""
+
+		return {} if 'data' not in self.data else self.data['data']
