@@ -5,4 +5,9 @@ This file is part of the MerchantAPI package.
 
 For the full copyright and license information, please view the LICENSE
 file that was distributed with this source code.
-"""
\ No newline at end of file
+"""
+
+from . import helper
+
+helper.configure_logging()
+helper.configure_permissions()
\ No newline at end of file
