@@ -1001,28 +1001,17 @@ def get_module(code: str):
 
 
 def get_page(code: str):
-	list_response = send_admin_request( 'PageList_Load_Query', {
-		'Filter': [
-			{
-				'name':	'search',
-				'value':
-				[
-					{
-						'field':		'code',
-						'operator':		'EQ',
-						'value':		code
-					}
-				]
-			}
-		]
-	})
+	request = merchantapi.request.PageListLoadQuery(init_client())
 
-	list_result = list_response.json()
+	request.get_filters().equal('code', code)
+	request.set_on_demand_columns(request.get_available_on_demand_columns())
+	request.add_on_demand_column('CustomField_Values:*')
 
-	assert list_result['success'] in (True, 1)
-	assert 'data'in list_result
-	assert 'data' in list_result['data']
-	return None if len(list_result['data']['data']) == 0 else merchantapi.model.Page(list_result['data']['data'][0])
+	response = request.send()
+
+	validate_response_success(response, merchantapi.response.PageListLoadQuery)
+
+	return response.get_pages()[0] if len(response.get_pages()) else None
 
 
 def reset_branch_state():
@@ -1045,53 +1034,35 @@ def reset_branch_state():
 
 
 def get_css_resource(code: str):
-	list_response = send_admin_request( 'CSSResourceList_Load_Query', {
-		'Filter': [
-			{
-				'name':	'search',
-				'value':
-				[
-					{
-						'field':		'code',
-						'operator':		'EQ',
-						'value':		code
-					}
-				]
-			}
-		]
-	})
+	request = merchantapi.request.CSSResourceListLoadQuery(init_client())
 
-	list_result = list_response.json()
+	filters = request.filter_expression()\
+		.equal('code', code)
 
-	assert list_result['success'] in (True, 1)
-	assert 'data'in list_result
-	assert 'data' in list_result['data']
-	return None if len(list_result['data']['data']) == 0 else merchantapi.model.CSSResource(list_result['data']['data'][0])
+	request.set_filters(filters) \
+		.set_on_demand_columns(request.get_available_on_demand_columns())
+
+	response = request.send()
+
+	validate_response_success(response, merchantapi.response.CSSResourceListLoadQuery)
+
+	return response.get_css_resources()[0] if len(response.get_css_resources()) else None
 
 
 def get_javascript_resource(code: str):
-	list_response = send_admin_request( 'JavaScriptResourceList_Load_Query', {
-		'Filter': [
-			{
-				'name':	'search',
-				'value':
-				[
-					{
-						'field':		'code',
-						'operator':		'EQ',
-						'value':		code
-					}
-				]
-			}
-		]
-	})
+	request = merchantapi.request.JavaScriptResourceListLoadQuery(init_client())
 
-	list_result = list_response.json()
+	filters = request.filter_expression()\
+		.equal('code', code)
 
-	assert list_result['success'] in (True, 1)
-	assert 'data'in list_result
-	assert 'data' in list_result['data']
-	return None if len(list_result['data']['data']) == 0 else merchantapi.model.JavaScriptResource(list_result['data']['data'][0])
+	request.set_filters(filters) \
+		.set_on_demand_columns(request.get_available_on_demand_columns())
+
+	response = request.send()
+
+	validate_response_success(response, merchantapi.response.JavaScriptResourceListLoadQuery)
+
+	return response.get_javascript_resources()[0] if len(response.get_javascript_resources()) else None
 
 
 def get_price_group_exclusion(priceGroup: str, excudedPriceGroup: str):
@@ -1107,3 +1078,24 @@ def get_price_group_exclusion(priceGroup: str, excudedPriceGroup: str):
 		if pg['name'] == excudedPriceGroup:
 			return pg
 	return None
+
+
+def get_copy_product_rule(name: str):
+	request = merchantapi.request.CopyProductRulesListLoadQuery(init_client())
+	request.get_filters().equal('name', name)
+	response = request.send()
+
+	validate_response_success(response, merchantapi.response.CopyProductRulesListLoadQuery)
+
+	return response.get_copy_product_rules()[0] if len(response.get_copy_product_rules()) else None
+
+
+def get_copy_page_rule(name: str):
+	request = merchantapi.request.CopyPageRulesListLoadQuery(init_client())
+	request.get_filters().equal('name', name)
+
+	response = request.send()
+
+	validate_response_success(response, merchantapi.response.CopyPageRulesListLoadQuery)
+
+	return response.get_copy_page_rules()[0] if len(response.get_copy_page_rules()) else None
